import requests

import vdcpy.config as config


def get_networks(
    network_id=None, source=None, target=None, bandwidth=None, packet_loss=None):
    """
    Get a list of networks from the VDC API.

    Parameters
    ----------
    network_id : str
        The ID of the network to retrieve.
    source : str
        The source of the network to retrieve.
    target : str
        The target of the network to retrieve.
    bandwidth : str
        The bandwidth of the network to retrieve.
    packet_loss : str
        The packet loss of the network to retrieve.
    
    Returns
    -------
    network_list : list
        A list of networks.
    """
    network_list = []
    query = f'{config.API_URL}/{config.NETWORK_NAMESPACE}'
    if network_id is not None:
        query += f'?id={network_id}'
    if source is not None:
        if network_id is None:
            query += f'?source={source}'
        else:
            query += f'&source={source}'
    if target is not None:
        if network_id is None and source is None:
            query += f'?target={target}'
        else:
            query += f'&target={target}'
    if bandwidth is not None:
        if network_id is None and source is None and target is None:
            query += f'?bandwidth={bandwidth}'
        else:
            query += f'&bandwidth={bandwidth}'
    if packet_loss is not None:
        if network_id is None and source is None and target is None and bandwidth is None:
            query += f'?packet_loss={packet_loss}'
        else:
            query += f'&packet_loss={packet_loss}'
    response = requests.get(query)
    if response.status_code == 200:
        network_list = response.json()
    return network_list


def delete_network(network_id):
    """
    Delete a network from the VDC API.

    Parameters
    ----------
    network_id : str
        The ID of the network to delete.
    
    Returns
    -------
    response : requests.models.Response
        The response from the VDC API.
    """
    query = f'{config.API_URL}/{config.NETWORK_NAMESPACE}/{network_id}'
    response = requests.delete(query)
    if response.status_code == 204:
        return True
    else:
        raise Exception(f'Error deleting network: {response.status_code}')


def add_network(network_info):
    """
    Add a network to the VDC API.

    Parameters
    ----------
    network_info : dict
        The network information to add.
    
    Returns
    -------
    network_info : dict
        The network information added.
    """
    query = f'{config.API_URL}/{config.NETWORK_NAMESPACE}'
    response = requests.post(query, json=network_info)
    network_info = response.json()
    return network_info


def delete_network(network_id):
    """
    Delete a network from the VDC API.

    Parameters
    ----------
    network_id : str
        The ID of the network to delete.
    
    Returns
    -------
    response : requests.models.Response
        The response from the VDC API.
    """
    query = f'{config.API_URL}/{config.NETWORK_NAMESPACE}/{network_id}'
    response = requests.delete(query)
    if response.status_code == 204:
        return True
    else:
        raise Exception(f'Error deleting network: {response.status_code}')
